import React, {useState} from 'react';
import {
  StyleSheet,
  View,
  TextInput,
  FlatList,
  Text,
  ScrollView,
  TouchableOpacity,
} from 'react-native';
import {onConfigurations} from '../../common/helper';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import {Dropdown} from 'react-native-material-dropdown';

FontAwesome.loadFont();

export default (props) => {
  const {item, dispatch} = props;
  const configurations = JSON.parse(item.configurations);
  const dataQuestion = configurations.paragraph_sections[0];
  const dataSelect = configurations.correct_answer[0];
  dataSelect.sort();

  const dataSelectNew = [];
  const dataAnswer = [];

  dataSelect.forEach((i) => {
    const newItem = {value: i, answer: ''};
    dataSelectNew.push(newItem);
    dataAnswer.push('');
  });

  const [data, setData] = useState(dataAnswer);

  const setDataAnswer = (answer, index) => {
    data[index] = answer;
    onConfigurations(item, data, dispatch);
  };

  return (
    <View style={[styles.configView]}>
      <ScrollView
        contentContainerStyle={{
          flexDirection: 'row',
          flexWrap: 'wrap',
        }}>
        {dataQuestion.map((item, index) => (
          <View style={styles.containerQues} key={index}>
            <Text
              style={{
                fontSize: 16,
                lineHeight: 24,
              }}>
              {item.replace('*', '')}
            </Text>
            {item.includes('*') ? (
              <TextInput
                underlineColorAndroid="transparent"
                style={styles.textInput}
                returnKeyType="done"
                autoCapitalize="none"
                onChangeText={(text) => setDataAnswer(text, index)}
              />
            ) : (
              item.includes('(') && (
                <View style={{flexDirection: 'row', alignItems: 'center'}}>
                  <View style={styles.viewDropdown}>
                    <Dropdown
                      style={{alignItems: 'center'}}
                      containerStyle={styles.contentStyle}
                      inputContainerStyle={{
                        borderBottomWidth: 0,
                      }}
                      labelHeight={0}
                      data={dataSelectNew}
                      rippleOpacity={0}
                      baseColor="orange"
                      renderAccessory={() => null}
                      onChangeText={(value) => setDataAnswer(value, index)}
                      renderBase={({value}) => {
                        return (
                          <Text
                            style={{
                              textAlign: 'center',
                              color: 'black',
                              fontSize: 16,
                              marginTop: 2,
                            }}>
                            <Text>{value}</Text>
                          </Text>
                        );
                      }}
                    />
                  </View>
                </View>
              )
            )}
          </View>
        ))}
      </ScrollView>
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    width: '100%',
    minHeight: 300,
    paddingHorizontal: 20,
    alignItems: 'center',
  },
  containerQues: {
    flexDirection: 'row',
    marginVertical: 5,
    flexWrap: 'wrap',
    alignItems: 'center',
  },
  textInput: {
    color: 'black',
    fontSize: 14,
    textAlign: 'center',
    minWidth: 80,
    paddingVertical: 6,
    borderColor: '#F5A237',
    borderRadius: 20,
    borderWidth: 1,
    marginHorizontal: 5,
    paddingHorizontal: 8,
  },
  viewTextType2: {
    minWidth: 80,
    fontSize: 14,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    color: 'red',
    textAlign: 'center',
  },
  viewBorder: {
    minWidth: 80,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    alignItems: 'center',
  },
  viewDropdown: {
    marginHorizontal: 8,
    borderColor: '#F5A237',
    borderWidth: 1,
    paddingHorizontal: 8,
    borderRadius: 20,
    justifyContent: 'center',
  },
  contentStyle: {
    height: 30,
    minWidth: 80,
    paddingTop: 2,
  },
});
