import React, {useState, useRef, useEffect} from 'react';
import {
  StyleSheet,
  View,
  Text,
  Image,
  ScrollView,
  PanResponder,
} from 'react-native';
import Swiper from '../../../components/swiper';
import Icon from 'react-native-vector-icons/Ionicons';
import {createSelector} from 'reselect';
import {useDispatch, useSelector} from 'react-redux';
import Video from 'react-native-video';
import * as actions from '../../../redux/actions';

import SingleChoice from '../../../components/single-choice';
import MultipleChoice from '../../../components/multiple-choice';
import Writing from '../../../components/writing';
import AudioRecording from '../../../components/audio-recording';
import Reorder from '../../../components/reorder/index2';
import Matching from '../../../components/matching';
import FillInTheBlank from '../../../components/fill-in-the-blank';

import * as TYPE from '../../../common/constant';
import {onConfigurations} from '../../../common/helper';
import HTMLView from 'react-native-htmlview';

Icon.loadFont();
const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

const getKey = createSelector(
  (state) => state.reducerComponents,
  (reducerComponents) => reducerComponents,
);
const getUserAnswer = createSelector(
  (state) => state.submitData,
  (submitData) => submitData,
);
export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  let player = useRef();
  const [paused, setPause] = useState(false);
  const [muted, setMute] = useState(false);
  const {data, loading, error} = useSelector(getData);
  const {user_answer} = useSelector(getUserAnswer);
  const {keyPage} = useSelector(getKey);
  const {test_data} = data;
  const {sections} = test_data;
  const sectionsData = sections.map((e, index) => {
    const section_id = e.id;
    const section_tag = e.tag;
    const questions = e.questions;
    const outline_s = e.outline;
    const questionsData = questions.map((item) => {
      return {...item, section_id, section_tag, outline_s};
    });
    return questionsData;
  });

  const questions = sectionsData.flat();

  const onPauseAudio = (type) => {
    if (player) {
      if (type === 'Record') {
        setMute(true);
      } else {
        setMute(false);
      }
    }
  };

  const replayAudio = () => {
    setPause(true);
    setTimeout(() => {
      setPause(false);
    }, 3000);
  };

  return (
    <View>
      {JSON.parse(questions[keyPage].extra) !== null && (
        <View>
          {JSON.parse(questions[keyPage].extra).map((e, key) => {
            return (
              <View key={key}>
                {e.type === 'audio' && (
                  <Video
                    ref={(ref) => (player = ref)}
                    audioOnly={true}
                    source={{uri: e.value}}
                    repeat={true}
                    paused={paused}
                    muted={muted}
                    // onEnd={() => replayAudio()}
                  />
                )}
              </View>
            );
          })}
        </View>
      )}

      <Swiper setMute={() => setMute(false)} route={route.params?.nav}>
        {questions.map((item, i) => {
          const extra =
            JSON.parse(item.extra) === null ? [] : JSON.parse(item.extra);
          const configurations = JSON.parse(item.configurations);

          const type = item.type;
          const {outline, outline_s} = item;
          return (
            <View style={[styles.slide]} key={i}>
              <Text style={styles.title}>{item.title}</Text>
              {outline_s ? (
                <HTMLView value={outline_s} style={{marginHorizontal: 20}} />
              ) : null}
              {outline ? (
                <HTMLView value={outline} style={{marginHorizontal: 20}} />
              ) : null}
              <View style={styles.viewImage}>
                {extra !== null && (
                  <View>
                    {extra.map((e, key) => {
                      return (
                        <View key={key}>
                          {/* {e.type === 'audio' && <Video source={{uri: e.value}} />} */}
                          {e.type === 'image' && (
                            <View>
                              <Image
                                source={{uri: e.value}}
                                style={{width: 250, height: 250}}
                                resizeMode="contain"
                              />
                            </View>
                          )}
                        </View>
                      );
                    })}
                  </View>
                )}
              </View>
              <View>
                {Array.isArray(configurations) ? (
                  configurations.map((items, key) => {
                    const check = user_answer.some((i) => {
                      let valueChoose = i.user_answer.value;
                      switch (i.type) {
                        case TYPE.MULTIPLE_CHOICE: {
                          // if (item.id === 70) {
                          //   console.log(146, valueChoose, items.value);
                          // }
                          if (i.question_id === item.id) {
                            const selected = valueChoose.some(
                              (s) => s === items.value,
                            );
                            return selected;
                          }
                          return false;
                        }
                        case TYPE.SINGLE_CHOICE: {
                          return (
                            valueChoose === items.value &&
                            i.question_id === item.id
                          );
                        }
                      }
                    });
                    return (
                      <View key={key}>
                        <View>
                          {type === TYPE.SINGLE_CHOICE && (
                            <SingleChoice
                              data={items.data}
                              text={items.data.value}
                              onPress={() => {
                                onConfigurations(
                                  {...item, items},
                                  user_answer,
                                  dispatch,
                                );
                              }}
                              check={check}
                            />
                          )}
                        </View>
                        <View>
                          {type === TYPE.MULTIPLE_CHOICE && (
                            <MultipleChoice
                              onPress={() =>
                                onConfigurations(
                                  {...item, items},
                                  user_answer,
                                  dispatch,
                                )
                              }
                              data={items.data}
                              check={check}
                            />
                          )}
                        </View>
                      </View>
                    );
                  })
                ) : (
                  <View style={{marginTop: 10}}>
                    {type === TYPE.WRITING && (
                      <Writing item={item} dispatch={dispatch} />
                    )}
                    {type === TYPE.REORDER && (
                      <Reorder item={item} dispatch={dispatch} />
                    )}
                    {type === TYPE.MATCHING && (
                      <Matching item={item} dispatch={dispatch} />
                    )}
                    {type === TYPE.FILL_IN_THE_BLANK && (
                      <FillInTheBlank item={item} dispatch={dispatch} />
                    )}
                  </View>
                )}
              </View>
              {type === TYPE.AUDIO_RECORDING && (
                <AudioRecording
                  item={item}
                  onPauseAudio={(type) => onPauseAudio(type)}
                />
              )}
            </View>
          );
        })}
      </Swiper>
    </View>
  );
};

const styles = StyleSheet.create({
  safe: {
    flex: 1,
  },
  slide: {
    paddingTop: 20,
    backgroundColor: '#fff',
    alignItems: 'center',
  },
  // Header styles
  header: {
    color: '#FFFFFF',
    fontFamily: 'Avenir',
    fontSize: 30,
    fontWeight: 'bold',
    marginVertical: 10,
  },
  // Text below header
  text: {
    color: '#FFFFFF',
    fontSize: 18,
    marginHorizontal: 40,
    textAlign: 'center',
  },
  title: {
    fontSize: 23,
    fontWeight: 'bold',
    marginBottom: '1%',
    marginHorizontal: 20,
  },
  viewImage: {
    marginBottom: '1%',
  },
});
